﻿© 2009 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub TDS6000B/C Main Trigger IEEE
INSTRUMENT:            Sub TDS6000B/C Delay Trigger IEEE
INSTRUMENT:            Sub TDS6000B/C Check for Trigger IEEE
DATE:                  2009-10-07 16:02:42
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       5
NUMBER OF LINES:       252
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        TDS6604B, TDS6804B, TDS6124C, TDS6154C
#
#  Compatibility:
#        MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
# REGISTERS USED:
#
#   You will notice that MEM & MEM1 are used extensively in this procedure.
#   This can be dangerous to use since MEM and MEM1 are used for controlling
#   instruments.  We read the values from MEM and MEM1 and store these in
#   temporary registers which are later restored on exiting the sub-procedure.
#
#   Global Variables
#
#     @Query (was S[5])
#
#     M[10] No longer supported
#       This variable is used to set watchdog timer in the event the
#       oscillscope does not respond to a command.
#
#     @DelayTimebase (was M[20])
#       This global variable is used to designate the timebase trigger adjust
#       (1 = Delayed Timebase, 0 = Main Timebase)
#
#     @HorzPosStart (was M[1])
#       This register is the horizontal start position for the Cursor Walker
#       subprocedure.
#
#     @HorzPosIncr (was M[2])
#       This global variable is the horizontal increment for the Cursor Walker
#       subprocedure.
#
#     @StartTrigLevel (was M[3])
#       This global variable is the starting trigger level for the Main and
#       Delay Trigger subprocedures.
#
#     @TargetAmpl (was M[4])
#       This register is the target for the cursor walker, or the trigger
#       level increment for the Main Trigger and Delay Trigger subprocedures.
#
#     @MeasRes (was M[17])
#       Measurement resolution
#
#   TrigSrc (was S[6])
#     This variable is used to store the trigger "MAIN" or "DELAY".
#
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         BackupMEM = MEM; BackupMEM1 = MEM1

  1.002  JMPL         MAIN_TRIGGER                 PSUBI("Main Trigger")
  1.003  JMPL         DELAY_TRIGGER                PSUBI("Delay Trigger")
  1.004  JMPL         CHECK_FOR_TRIGGER            PSUBI("Check for Trigger")
  1.005  DISP         Undefined subprocedure!
  1.006  END

  1.007  EVAL   Increment step number

# =====  Sub TDS6000B/C Main Trigger IEEE  =================================

  2.001  LABEL        MAIN_TRIGGER
  2.002  MATH         @DelayTimebase = 0; MaxTries = 100
  2.003  MATH         MaxGoodReadings = 10

  2.004  LABEL        CHECK_MAIN_TRIGGER
# Trigger Level we will start with.
  2.005  IEEE2        TRIGGER:MAIN SETLEVEL;MAIN:LEVEL [V @StartTrigLevel]
  2.006  MATH         Counter = 0; @NumTries = 0; Done = 0

  2.007  DO
  2.008  LABEL        TEST_MAIN_LEVEL
# Increment Master Watchdog counter
  2.009  MATH         Counter = Counter + 1

# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  2.010  IF           Counter >= MaxTries
# Set a value for @NumTries which will later be evaluated as a failure
  2.011  MATH         @NumTries = 0; Done = 1

  2.012  ELSE
  2.013  WAIT         [D250]
# Read the Trigger State
  2.014  IEEE         TRIGGER:STATE?[I$]
  2.015  MATH         @Triggered = FIND(MEM2, "TRIG", 1)

# If MAIN TRIGGER was called from DELAY TRIGGER, PARTial is ok.
  2.016  IF           @DelayTimebase
  2.017  MATH         @Triggered = @Triggered || FIND(MEM2, "PART", 1)
  2.018  ENDIF

  2.019  IF           @Triggered
# Increment the good trigger counter
  2.020  MATH         @NumTries = @NumTries + 1
# End the loop if the system records over 10 good triggers
  2.021  MATH         Done = (@NumTries > MaxGoodReadings)
# Go back to the trigger beginning
  2.022  ELSE
# Reset the good trigger counter
  2.023  MATH         @NumTries = 0

# If we counted too high, start over
  2.024  IF           MEM >= ABS(@StartTrigLevel)
  2.025  MATH         MEM = @StartTrigLevel
  2.026  ENDIF

  2.027  WAIT         [D100]
  2.028  MATH         MEM = MEM + @TargetAmpl
  2.029  IEEE2        TRIGGER:MAIN:LEVEL [MEM]
  2.030  ENDIF

  2.031  HEAD         MAIN TRIGGER LEVEL: [MEM] V
  2.032  ENDIF

  2.033  UNTIL        Done

  2.034  JMPL         CHECK_DELAY_TRIGGER          @DelayTimebase
  2.035  JMPL         RESTORE_MEM_AND_MEM1

  2.036  EVAL   Increment step number

# ====== Sub TDS6000B/C Delay Trigger IEEE =================================

  3.001  LABEL        DELAY_TRIGGER
  3.002  MATH         @DelayTimebase = 1; MaxTries = 100

  3.003  LABEL        CHECK_DELAY_TRIGGER
# Set a flag
  3.004  MATH         Counter = 0; @NumTries = 0
  3.005  IEEE2        TRIGGER:DELAY:LEVEL [V @StartTrigLevel]

  3.006  LABEL        TEST_DELAY_LEVEL
# Increment Master Watchdog counter
  3.007  MATH         Counter = Counter + 1
  3.008  JMPL         FAIL_DELAY_TRIGGER           Counter >= 100
  3.009  WAIT         [D250]
# Read the Trigger State
  3.010  IEEE         TRIGGER:STATE?[I$]
# If "REAdy", we need to re-adjust the main trigger level.
  3.011  JMPL         CHECK_MAIN_TRIGGER           FIND(MEM2, "REA", 1)
  3.012  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
# If "PARTial", we need to adjust the delay trigger Level.
  3.013  JMPL         ADJUST_DELAY_LEVEL           FIND(MEM2, "PART", 1)
# Increment the good trigger counter
  3.014  MATH         @NumTries = @NumTries + 1
# Jump out of the loop if the system records over 10 good triggers
  3.015  JMPL         END_DELAY_TRIGGER            @NumTries > 10
# Go back to the trigger beginning
  3.016  JMPL         TEST_DELAY_LEVEL

  3.017  LABEL        ADJUST_DELAY_LEVEL
# Reset the good trigger counter
  3.018  MATH         @NumTries = 0
# If we counted too high, start over
  3.019  JMPL         DELAY_ADD_LEVEL              MEM < ABS(@StartTrigLevel)
  3.020  MATH         MEM = @StartTrigLevel

  3.021  LABEL        DELAY_ADD_LEVEL
  3.022  WAIT         [D100]
  3.023  MATH         MEM = MEM + @TargetAmpl
  3.024  IEEE2        TRIGGER:DELAY:LEVEL [MEM]
  3.025  HEAD         DELAY TRIGGER LEVEL: [MEM] V
  3.026  JMPL         TEST_DELAY_LEVEL

  3.027  LABEL        FAIL_DELAY_TRIGGER
# Set a value for @NumTries which will later be evaluated as a failure
  3.028  MATH         @NumTries = 0

  3.029  LABEL        END_DELAY_TRIGGER
  3.030  JMPL         RESTORE_MEM_AND_MEM1

  3.031  EVAL   Increment step number

# ====== Sub TDS6000B/C Check for Trigger IEEE =============================

  4.001  LABEL        CHECK_FOR_TRIGGER
  4.002  MATH         ElapsedSecs = 0; MaxSecs = 5; @Abort = 0

# Wait up to 5 s for UUT to trigger.
  4.003  DO
  4.004  IEEE         TRIGGER:STATE?[I$]
  4.005  MATH         @Triggered = FIND(MEM2, "TRIG", 1)

  4.006  IF           NOT(@Triggered)
  4.007  WAIT         [D1000]
  4.008  MATH         ElapsedSecs = ElapsedSecs + 1
  4.009  ENDIF

  4.010  UNTIL        @Triggered || (ElapsedSecs > MaxSecs)

  4.011  IF           ElapsedSecs > MaxSecs
  4.012  OPBR         -z [V ElapsedSecs] s have elapsed, and UUT is not
  4.012  OPBR         not trigger.
  4.012  OPBR
  4.012  OPBR         Do you wish to try again?
  4.013  MATH         @Abort = NOT(MEM1)
  4.014  ENDIF

  4.015  MATH         BackupMEM1 = @Triggered
  4.016  JMPL         RESTORE_MEM_AND_MEM1

  4.017  EVAL   Increment step number

  5.001  LABEL        RESTORE_MEM_AND_MEM1
  5.002  MATH         MEM = BackupMEM; MEM1 = BackupMEM1
  5.003  END
